@@ -397,7 +397,7 @@ func (mf *metricFamily) addSeries(seriesRef uint64, metricName string, ls labels
 			mg.ts = t
 			mg.count = v
 			mg.hasCount = true
-		case metricName == mf.metadata.Metric+metricSuffixCreated:
+		case metricName == mf.metadata.MetricFamily+metricSuffixCreated:
 			mg.created = v
 		default:
 			boundary, err := getBoundary(mf.mtype, ls)
@@ -407,11 +407,11 @@ func (mf *metricFamily) addSeries(seriesRef uint64, metricName string, ls labels
 			mg.complexValue = append(mg.complexValue, &dataPoint{value: v, boundary: boundary})
 		}
 	case pmetric.MetricTypeExponentialHistogram:
-		if metricName == mf.metadata.Metric+metricSuffixCreated {
+		if metricName == mf.metadata.MetricFamily+metricSuffixCreated {
 			mg.created = v
 		}
 	case pmetric.MetricTypeSum:
-		if metricName == mf.metadata.Metric+metricSuffixCreated {
+		if metricName == mf.metadata.MetricFamily+metricSuffixCreated {
 			mg.created = v
 		} else {
 			mg.value = v
