@@ -16,3 +16,12 @@ type Indexed interface {
 	// Size should return the size for the collection.
 	Size() int
 }
+
+// RemovableIndexed describes an indexed collection that can remove items.
+// Must be implemented to use [Expr.Remove].
+type RemovableIndexed interface {
+	Indexed
+
+	// RemoveValueAtIndex removes an item from the collection.
+	RemoveValueAtIndex(index int)
+}
