@@ -11,6 +11,7 @@ import (
 	"io"
 	"net/http"
 	"net/url"
+	"os"
 	"runtime"
 	"slices"
 	"strconv"
@@ -54,6 +55,8 @@ const (
 	AuthTypeOAuthAuthorizationCode
 	// AuthTypeOAuthClientCredentials is to use non-interactive OAuth2 flow
 	AuthTypeOAuthClientCredentials
+	// AuthTypeWorkloadIdentityFederation is to use CSP identity for authentication
+	AuthTypeWorkloadIdentityFederation
 )
 
 func (authType AuthType) isOauthNativeFlow() bool {
@@ -96,6 +99,9 @@ func determineAuthenticatorType(cfg *Config, value string) error {
 	} else if upperCaseValue == AuthTypeOAuthClientCredentials.String() {
 		cfg.Authenticator = AuthTypeOAuthClientCredentials
 		return nil
+	} else if upperCaseValue == AuthTypeWorkloadIdentityFederation.String() {
+		cfg.Authenticator = AuthTypeWorkloadIdentityFederation
+		return nil
 	} else {
 		// possibly Okta case
 		oktaURLString, err := url.QueryUnescape(lowerCaseValue)
@@ -151,6 +157,8 @@ func (authType AuthType) String() string {
 		return "OAUTH_AUTHORIZATION_CODE"
 	case AuthTypeOAuthClientCredentials:
 		return "OAUTH_CLIENT_CREDENTIALS"
+	case AuthTypeWorkloadIdentityFederation:
+		return "WORKLOAD_IDENTITY"
 	default:
 		return "UNKNOWN"
 	}
@@ -196,6 +204,7 @@ type authRequestData struct {
 	ProofKey                string                       `json:"PROOF_KEY,omitempty"`
 	Token                   string                       `json:"TOKEN,omitempty"`
 	OauthType               string                       `json:"OAUTH_TYPE,omitempty"`
+	Provider                string                       `json:"PROVIDER,omitempty"`
 }
 type authRequest struct {
 	Data authRequestData `json:"data"`
@@ -529,6 +538,19 @@ func createRequestBody(sc *snowflakeConn, sessionParameters map[string]interface
 		requestMain.LoginName = sc.cfg.User
 		requestMain.Token = token
 		requestMain.OauthType = "OAUTH_CLIENT_CREDENTIALS"
+	case AuthTypeWorkloadIdentityFederation:
+		if !experimentalAuthEnabled() {
+			return nil, errors.New("workload identity authentication is not ready to use")
+		}
+		logger.WithContext(sc.ctx).Debug("Workload Identity Federation")
+		wifAttestationProvider := createWifAttestationProvider(sc.ctx)
+		wifAttestation, err := wifAttestationProvider.getAttestation(sc.cfg.WorkloadIdentityProvider)
+		if err != nil {
+			return nil, err
+		}
+		requestMain.Authenticator = AuthTypeWorkloadIdentityFederation.String()
+		requestMain.Token = wifAttestation.Credential
+		requestMain.Provider = wifAttestation.ProviderType
 	}
 
 	authRequest := authRequest{
@@ -541,6 +563,11 @@ func createRequestBody(sc *snowflakeConn, sessionParameters map[string]interface
 	return jsonBody, nil
 }
 
+func experimentalAuthEnabled() bool {
+	val, ok := os.LookupEnv("SF_ENABLE_EXPERIMENTAL_AUTHENTICATION")
+	return ok && strings.EqualFold(val, "true")
+}
+
 // Generate a JWT token in string given the configuration
 func prepareJWTToken(config *Config) (string, error) {
 	if config.PrivateKey == nil {
